#!/bin/bash
# packager          : Frederic Boulet <bipbip> bipbiponlinux~AT~gmail.com
# package           : asunder
# homepage          : http://littlesvr.ca/asunder/
# dependency        : GTK+ 2.2.x.,libcddb,cdparanoia,lame,vorbis-tools,flac 

softname='asunder'
softversion='2.0'
packageversion='66.1'

arch='i686'
cpu='i686'

prefix=/usr

# log
(

# parameters needed for the build process
buildir=$(pwd)
src="$buildir/$softname-$softversion"
srcpkg="$buildir/$softname-$softversion.tar.bz2"
package="$softname-$softversion-$arch-$packageversion"
dest="$buildir/$package"
source=http://littlesvr.ca/asunder/releases/$softname-$softversion.tar.bz2

# prepare the build result directory
rm -rf $dest
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/$prefix/bin
mkdir -p $dest/usr/share/applications
mkdir -p $dest/usr/share/icons/hicolor/48x48/apps
mkdir -p $dest/usr/doc
mkdir -p $dest/usr/src/$softname-$softversion

# Slack-desc
cat <<EOF > $dest/install/slack-desc 
       |-----handy-ruler------------------------------------------------------|
asunder: asunder - a graphical Audio CD ripper and encoder for Linux
asunder:
asunder: You can use it to save tracks from an Audio CD as WAV, MP3, 
asunder: OGG, and/or FLAC.
asunder: 
asunder: 
asunder: 
asunder:
asunder:
asunder:
asunder:
EOF

# check if source is present
if [ -f $softname-$softversion.tar.bz2 ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c --no-check-certificate $source
fi

# extract the source code 
cd $buildir
tar xjvf $srcpkg
cd $src	

# building
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
    
./configure \
	--program-prefix="" \
	--program-suffix="" \
	--prefix="/usr" \
	--sysconfdir="/etc" \
	--localstatedir="/var" \
	--mandir="/usr/man" \
	--infodir="/usr/info" \
	--enable-static="no" \
	--enable-shared="yes" \
	--build=$arch-slackware-linux || exit

make 
make install DESTDIR=$dest
   
# "make" icon
cd $dest/usr/share/icons/hicolor/48x48/apps/
ln -s ../../../../pixmaps/$softname.png $softname.png

# "make" .desktop
cat << "EOF" > $dest/usr/share/applications/$softname.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Asunder
Comment=CD player/ripper
Comment[ca]=Reproductor/extractor de CD d'audio
Comment[es]=Reproductor/extractor de CDs de audio
Comment[de]=Audio-CDs rippen und MP3s/OGGs kodieren
Comment[fr]=Lecteur/extracteur de CD audio
Comment[fi]=CD-audion soitto- ja kopiointiohjelma
Exec=asunder
Terminal=false
Type=Application
Categories=Application;AudioVideo;
Icon=asunder
EOF

# add 'default' files
	cd $src
    mkdir -p $dest/usr/doc/$softname-$softversion
    cp -a \
      AUTHORS COPYING ChangeLog INSTALL NEWS README TODO\
      $dest/usr/doc/$softname-$softversion
	
# Strip Executables
( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

# put the ZenWalk build in the right directory
cd $buildir
cp build-$softname.sh $dest/$prefix/src/$softname-$softversion

# set target permissions
chown -R root.root $dest

cd $dest
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# real packaging work
cd $dest
makepkg -l y -c n $dest.txz

# .md5
cd $buildir
md5sum $package.txz > $package.md5

# .dep
cd $buildir
echo -e "atk,cairo,expat,fontconfig,freetype,glib2,gtk+2,\
libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,\
libXfixes,libXi,libXinerama,libXrandr,libXrender,libcddb,libpng,libxcb,\
pango,pixman,xcb-util,zlib" > $package.dep

# erase source
rm -rf $src
rm -rf $dest

# log
) 2>&1 | tee "$softname-$softversion-build.log"
